==> alfresco-repository-23.7.0.8-sources.jar: lib3party/org/apache/chemistry/opencmis/server/support/wrapper/CallContextAwareCmisService.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package lib3party.org.apache.chemistry.opencmis.server.support.wrapper;

import org.apache.chemistry.opencmis.commons.server.CallContext;
import org.apache.chemistry.opencmis.commons.server.CmisService;

/**
 * Identifies a CMIS service object that can handle call contexts.
 */
public interface CallContextAwareCmisService extends CmisService {

    /**
     * Returns the current call context.
     * 
     * @return the call context
     */
    CallContext getCallContext();

    /**
     * Sets a new call context.
     * 
     * @param callContext
     *            the new call context
     */
    void setCallContext(CallContext callContext);
}

==> alfresco-repository-25.3.0.52-sources.jar: lib3party/org/apache/chemistry/opencmis/server/support/wrapper/CallContextAwareCmisService.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package lib3party.org.apache.chemistry.opencmis.server.support.wrapper;

import org.apache.chemistry.opencmis.commons.server.CallContext;
import org.apache.chemistry.opencmis.commons.server.CmisService;

/**
 * Identifies a CMIS service object that can handle call contexts.
 */
public interface CallContextAwareCmisService extends CmisService
{

    /**
     * Returns the current call context.
     * 
     * @return the call context
     */
    CallContext getCallContext();

    /**
     * Sets a new call context.
     * 
     * @param callContext
     *            the new call context
     */
    void setCallContext(CallContext callContext);
}
